Name: nodejs
Version: 6.14.1
Release: 1%{?dist}
Summary: JavaScript runtime
License: MIT and ASL 2.0 and ISC and BSD
Group: Development/Languages
URL: http://nodejs.org

# Exclusive archs must match v8
ExclusiveArch: %{ix86} x86_64 

# For NodeSource, we use the sources direct from nodejs.org/dist
Source0: node-v%{version}.tar.gz
Source1: etc-profiled-nodejs.sh
Source2: etc-profiled-nodejs.csh

Patch1: nodejs-disable-gyp-deps.patch
#Patch2: nodejs-use-system-certs.patch


%if 0%{?rhel} == 6
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildArch: %{_target_cpu}
BuildRequires: scl-utils
BuildRequires: python27
BuildRequires: python27-python
BuildRequires: devtoolset-3-gcc >= 4.8
BuildRequires: devtoolset-3-gcc-c++ >= 4.8
BuildRequires: zlib-devel
Requires: ca-certificates
%else
BuildRequires: python
BuildRequires: zlib-devel
#Requires: ca-certificates
%endif

#this corresponds to the "engine" requirement in package.json
Provides: nodejs(engine) = %{version}

# Node.js currently has a conflict with the 'node' package in Fedora
# The ham-radio group has agreed to rename their binary for us, but
# in the meantime, we're setting an explicit Conflicts: here
Conflicts: node <= 0.3.2-11

%description
Node.js is a platform built on Chrome\'s JavaScript runtime
for easily building fast, scalable network applications.
Node.js uses an event-driven, non-blocking I/O model that
makes it lightweight and efficient, perfect for data-intensive
real-time applications that run across distributed devices.

%package devel
Summary: JavaScript runtime - development headers
Group: Development/Languages
Requires: %{name}%{?_isa} == %{version}-%{release}
#Requires: nodejs-packaging

%description devel
Development headers for the Node.js JavaScript runtime.

%package docs
Summary: Node.js API documentation
Group: Documentation
BuildArch: noarch

%description docs
The API documentation for the Node.js JavaScript runtime.


%prep
%setup -q -n node-v%{version}


# remove bundled dependencies that we aren't building
%patch1 -p1
rm -rf deps/zlib

# remove bundled CA certificates
#%patch2 -p1
#rm -f src/node_root_certs.h

%build
export CFLAGS='%{optflags} -g -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'
export CXXFLAGS='%{optflags} -g -D_LARGEFILE_SOURCE -D_FILE_OFFSET_BITS=64'

%if 0%{?rhel} == 6
. /opt/rh/devtoolset-3/enable && . /opt/rh/python27/enable
./configure --prefix=%{_prefix} \
	  --shared-zlib \
           --without-dtrace 
           
%else
./configure --prefix=%{_prefix} \
           --without-dtrace \
	  --shared-zlib
%endif

# Setting BUILDTYPE=Debug builds both release and debug binaries
make BUILDTYPE=Debug %{?_smp_mflags}

%pre
if [ -d /usr/lib/node_modules/npm ]; then
  echo "Detected old npm client, removing..."
  rm -rf /usr/lib/node_modules/npm
fi

%install
rm -rf %{buildroot}

./tools/install.py install %{buildroot} %{_prefix}

mkdir -p %{buildroot}/etc/profile.d/
install -m 0755 %{SOURCE1} %{buildroot}/etc/profile.d/nodejs.sh
install -m 0755 %{SOURCE2} %{buildroot}/etc/profile.d/nodejs.csh

# and remove dtrace file again
rm -rf %{buildroot}/%{_prefix}/lib/dtrace

# Set the binary permissions properly
chmod 0755 %{buildroot}/%{_bindir}/node
chmod 0755 %{buildroot}/%{_bindir}/npm

# Install the debug binary and set its permissions
install -Dpm0755 out/Debug/node %{buildroot}/%{_bindir}/node_g

# own the sitelib directory
mkdir -p %{buildroot}%{_prefix}/lib/node_modules

#install documentation
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}-docs-%{version}/html
cp -pr doc/* %{buildroot}%{_defaultdocdir}/%{name}-docs-%{version}/html
rm -f %{_defaultdocdir}/%{name}-docs-%{version}/html/nodejs.1
cp -p LICENSE %{buildroot}%{_defaultdocdir}/%{name}-docs-%{version}/

#node-gyp needs common.gypi too
mkdir -p %{buildroot}%{_datadir}/node
cp -p common.gypi %{buildroot}%{_datadir}/node

%files
%doc AUTHORS BUILDING.md CHANGELOG.md COLLABORATOR_GUIDE.md CONTRIBUTING.md GOVERNANCE.md LICENSE README.md CODE_OF_CONDUCT.md
%{_bindir}/node
%{_bindir}/npm
%{_mandir}/man1/node.*
/etc/profile.d/*
%dir %{_prefix}/lib/node_modules
%{_prefix}/lib/node_modules/*
%dir %{_datadir}/node
%_defaultdocdir/node/lldb_commands.py
%_defaultdocdir/node/lldb_commands.pyc
%_defaultdocdir/node/lldb_commands.pyo
%_defaultdocdir/node/lldbinit

%files devel
%{_bindir}/node_g
%{_includedir}/node
%{_datadir}/node/common.gypi
%{_datadir}/systemtap/tapset/node.stp
%{_docdir}/node/gdbinit

%files docs
%{_defaultdocdir}/%{name}-docs-%{version}

%changelog
* Thu Apr 5 2018 Jacob Wang <jacob.wang@oracle.com> - 6.14.1-1.el7.nodepath
- update to 6.14.1

* Thu Mar 29 2018 Jacob Wang <jacob.wang@oracle.com> - 6.14.0-1.el7.nodepath
- update to 6.14.0

* Thu Mar 8 2018 Jacob Wang <jacob.wang@oracle.com> - 6.13.1-1.el7.nodepath
- update to 6.13.1

* Thu Mar 1 2018 Qing Lin <qing.lin@oracle.com> - 6.13.0-2.el7
- Add NODE_PATH support.

* Thu Feb 15 2018 Jacob Wang <jacob.wang@oracle.com> - 6.13.0-1.el7
- update to 6.13.0

* Thu Jan 4 2018 Jacob Wang <jacob.wang@oracle.com> - 6.12.3-1.el7
- update to 6.12.3

* Thu Dec 14 2017 Jacob Wang <jacob.wang@oracle.com> - 6.12.2-1.el7
- update to 6.12.2

* Thu Dec 7 2017 Jacob Wang <jacob.wang@oracle.com> - 6.12.1-1.el7
- update to 6.12.1

* Thu Nov 9 2017 Jacob Wang <jacob.wang@oracle.com> - 6.12.0-1.el7
- update to 6.12.0

* Thu Oct 26 2017 Jacob Wang <jacob.wang@oracle.com> - 6.11.5-1.el7
- update to 6.11.5

* Thu Oct 5 2017 Jacob Wang <jacob.wang@oracle.com> - 6.11.4-1.el7
- update to 6.11.4

* Thu Sep 7 2017 Jacob Wang <jacob.wang@oracle.com> - 6.11.3-1.el7
- update to 6.11.3

* Thu Aug 3 2017 Jacob Wang <jacob.wang@oracle.com> - 6.11.2-1.el7
- update to 6.11.2

* Thu Jul 13 2017 Jacob Wang <jacob.wang@oracle.com> - 6.11.1-1.el7
- update to 6.11.1

* Thu Jun 8 2017 Jacob Wang <jacob.wang@oracle.com> - 6.11.0-1.el7
- update to 6.11.0

* Thu May 4 2017 Jacob Wang <jacob.wang@oracle.com> - 6.10.3-1.el7
- update to 6.10.3
- 6.10.3 version re-writes the code of using SSL certificates, so nodejs-use-system-certs.patch
  can no longer patch to it. Nodejs will now load server certificates automatically.
  (Lans Hung <lans.hung@oracle.com>)

* Thu Apr 6 2017 Jacob Wang <jacob.wang@oracle.com> - 6.10.2-1.el7
- update to 6.10.2

* Thu Mar 23 2017 Jacob Wang <jacob.wang@oracle.com> - 6.10.1-1.el7
- update to 6.10.1

* Thu Feb 23 2017 Jacob Wang <jacob.wang@oracle.com> - 6.10.0-1.el7
- update to 6.10.0

* Thu Feb 2 2017 Jacob Wang <jacob.wang@oracle.com> - 6.9.5-1.el7
- update to 6.9.5

* Thu Jan 12 2017 Jacob Wang <jacob.wang@oracle.com> - 6.9.4-1.el7
- update to 6.9.4

* Thu Jan 5 2017 Jacob Wang <jacob.wang@oracle.com> - 6.9.3-1.el7
- update to 6.9.3

* Thu Dec 8 2016 Jacob Wang <jacob.wang@oracle.com> - 6.9.2-1.el7
- update to 6.9.2

* Wed Nov 16 2016 Jacob Wang <jacob.wang@oracle.com> - 6.9.1-1.el7
- update to 6.9.1

* Wed Aug 03 2016 Keshav Sharma <keshav.sharma@oracle.com> - 6.3.1-1
- Updated to upstream version 6.3.1

* Thu Jun 02 2016 Chris Lea <chl@nodesource.com> - 6.2.1
- https://nodejs.org/en/blog/release/v6.2.1/

* Tue May 17 2016 Chris Lea <chl@nodesource.com> - 6.2.0
- https://nodejs.org/en/blog/release/v6.2.0/

* Thu May 05 2016 Chris lea <chl@nodesource.com> - 6.1.0
- https://nodejs.org/en/blog/release/v6.1.0/

* Wed Apr 27 2016 Chris Lea <chl@nodesource.com> - 6.0.0
- https://nodejs.org/en/blog/release/v6.0.0/

* Sat Apr 23 2016 Chris Lea <chl@nodesource.com> - 5.11.0
- https://nodejs.org/en/blog/release/v5.11.0/

* Tue Apr 05 2016 Chris Lea <chl@nodesource.com> - 5.10.1
- https://nodejs.org/en/blog/release/v5.10.1/

* Thu Mar 31 2016 Chris Lea <chl@nodesource.com> - 5.10.0
- https://nodejs.org/en/blog/release/v5.10.0/

* Thu Mar 24 2016 Chris Lea <chl@nodesource.com> - 5.9.1
- https://nodejs.org/en/blog/release/v5.9.1/

* Wed Mar 16 2016 Chris Lea <chl@nodesource.com> - 5.9.0
- https://nodejs.org/en/blog/release/v5.9.0/

* Thu Mar 10 2016 Chris Lea <chl@nodesource.com> - 5.8.0
- https://nodejs.org/en/blog/release/v5.8.0/

* Wed Mar 02 2016 Chris Lea <chl@nodesource.com> - 5.7.1
- https://nodejs.org/en/blog/release/v5.7.1/

* Mon Feb 22 2016 Chris Lea <chl@nodesource.com> - 5.7.0
- https://nodejs.org/en/blog/release/v5.7.0/

* Tue Feb 09 2016 Chris Lea <chl@nodesource.com> - 5.6.0
- https://nodejs.org/en/blog/release/v5.6.0/

* Tue Jan 26 2016 Chris Lea <chl@nodesource.com> - 5.5.0
- Build for RHEL6 / CentOS6.

* Thu Jan 21 2016 Chris Lea <chl@nodesource.com> - 5.5.0
- https://nodejs.org/en/blog/release/v5.5.0/

* Tue Jan 12 2016 Chris Lea <chl@nodesource.com> - 5.4.1
- https://nodejs.org/en/blog/release/v5.4.1/

* Wed Jan 06 2016 Chris Lea <chl@nodesource.com> - 5.4.0
- https://nodejs.org/en/blog/release/v5.4.0/

* Wed Dec 16 2015 Chris Lea <chl@nodesource.com> - 5.3.0
- https://nodejs.org/en/blog/release/v5.3.0/

* Wed Dec 09 2015 Chris Lea <chl@nodesource.com> - 5.2.0
- https://nodejs.org/en/blog/release/v5.2.0/

* Thu Dec 03 2015 Chris Lea <chl@nodesource.com> - 5.1.1
- https://nodejs.org/en/blog/release/v5.1.1/

* Tue Nov 17 2015 Chris Lea <chl@nodesource.com> - 5.1.0
- Statically compile in ICU, do not depend on system libs.

* Tue Nov 17 2015 Chris Lea <chl@nodesource.com> - 5.1.0
- Update to 5.1.0.
- https://nodejs.org/en/blog/release/v5.1.0/

* Thu Nov 12 2015 Chris Lea <chl@nodesource.com> - 5.0.0
- Compile with --with-intl=system-icu
- Add dependency on libicu.

* Thu Oct 29 2015 Chris Lea <chl@nodesource.com> - 5.0.0
- Update to 5.0.0.
- https://nodejs.org/en/blog/release/v5.0.0/

* Tue Oct 13 2015 Chris Lea <chl@nodesource.com> - 4.2.1
- Update to 4.2.1.
- https://nodejs.org/en/blog/release/v4.2.1/

* Mon Oct 12 2015 Chris Lea <chl@nodesource.com> - 4.2.0
- Update to 4.2.0.
- https://nodejs.org/en/blog/release/v4.2.0/

* Mon Oct 05 2015 Chris Lea <chl@nodesource.com> - 4.1.2
- Update to 4.1.2.
- https://nodejs.org/en/blog/release/v4.1.2/

* Wed Sep 23 2015 Chris Lea <chl@nodesource.com> - 4.1.1
- Update to 4.1.1.
- https://nodejs.org/en/blog/release/v4.1.1/

* Thu Sep 17 2015 Chris Lea <chl@nodesource.com> - 4.1.0
- Update to 4.1.0.
- https://nodejs.org/en/blog/release/v4.1.0/

* Tue Sep 08 2015 Chris Lea <chl@nodesource.com> - 4.0.0
- New major release 4.0.0.
- NodeJS and IoJS have merged.
- https://nodejs.org/en/blog/release/v4.0.0/

* Fri Jul 10 2015 Chris Lea <chl@nodesource.com> - 0.12.7-1
- Package 0.12.7 for NodeSource.
- http://blog.nodejs.org/2015/07/10/node-v0-12-7-stable/

* Fri Jul 03 2015 Chris Lea <chl@nodesource.com> - 0.12.6-1
- New upstream release.
- http://blog.nodejs.org/2015/07/03/node-v0-12-6-stable/

* Thu Jun 25 2015 Chris Lea <chl@nodesource.com> - 0.12.5-1
- New upstream release.
- http://blog.nodejs.org/2015/06/22/node-v0-12-5-stable/

* Tue Mar 31 2015 Chris Lea <chl@nodesource.com> - 0.12.2-1
- New upstream release.
- http://blog.nodejs.org/2015/03/31/node-v0-12-2-stable

* Thu Mar 26 2015 Chris Lea <chl@nodesource.com> - 0.12.1-1
- New upstream release.
- New version of Openssl to fix security issues.

* Sun Feb 22 2015 Chris Lea <chl@nodesource.com> - 0.12.0-1
- New upstream release.

* Wed Jan 28 2015 Chris Lea <chl@nodesource.com> - 0.10.36-1
- Package 0.10.36 for NodeSource.
- openssl: update to 1.0.1l
- v8: Fix debugger and strict mode regression (Julien Gilli)
- v8: don't busy loop in cpu profiler thread (Ben Noordhuis)

* Wed Dec 24 2014 Chris Lea <chl@nodesource.com> - 0.10.35-1
- Package 0.10.35 for NodeSource.
- tls: re-add 1024-bit SSL certs removed by f9456a2 (Chris Dickinson)
- timers: don't close interval timers when unrefd (Julien Gilli)
- timers: don't mutate unref list while iterating it (Julien Gilli)

* Wed Sep 17 2014 Chris Lea <chl@nodesource.com> - 0.10.32-1
- Package 0.10.32 for NodeSource.

* Mon Aug 25 2014 Chris Lea <chris.lea@gmail.com> - 0.10.31-1
- First package for NodeSource
- new upstream release
